@@ -75,7 +75,7 @@ public:
      * @param library the library to create part from
      * Creates a part from the given @p library.
      */
-    KParts::ReadOnlyPart *createPart(const char *library);
+    Q_REQUIRED_RESULT KParts::ReadOnlyPart *createPart(const char *library);
 
     /**
      * @internal (for Plugin)
@@ -99,7 +99,7 @@ protected:
      * @param parent The parent widget.
      * @param flags The window flags.
      */
-    explicit Core(QWidget *parent = nullptr, Qt::WindowFlags flags = KDE_DEFAULT_WINDOWFLAGS);
+    explicit Core(QWidget *parent = nullptr, Qt::WindowFlags flags = {});
 
     /**
      * Returns the last error message for problems during
